# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_storebrowse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.enums_productinfo_pb2 as enums__productinfo__pb2
import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_storebrowse.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fsteammessages_storebrowse.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x17\x65nums_productinfo.proto\x1a\x0b\x65nums.proto\"A\n\x0bStoreItemID\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tpackageid\x18\x02 \x01(\r\x12\x10\n\x08\x62undleid\x18\x03 \x01(\r\"\xac\x01\n\x12StoreBrowseContext\x12\x10\n\x08language\x18\x01 \x01(\t\x12 \n\telanguage\x18\x02 \x01(\x05\x42\r\x82\xb5\x18\tELanguage\x12<\n\x0c\x63ountry_code\x18\x03 \x01(\tB&\x82\xb5\x18\"2-character country code; required\x12$\n\x0bsteam_realm\x18\x04 \x01(\x05\x42\x0f\x82\xb5\x18\x0b\x45SteamRealm\"\x8f\x04\n\x1aStoreBrowseItemDataRequest\x12\x16\n\x0einclude_assets\x18\x01 \x01(\x08\x12\x17\n\x0finclude_release\x18\x02 \x01(\x08\x12\x19\n\x11include_platforms\x18\x03 \x01(\x08\x12$\n\x1cinclude_all_purchase_options\x18\x04 \x01(\x08\x12\x1b\n\x13include_screenshots\x18\x05 \x01(\x08\x12\x18\n\x10include_trailers\x18\x06 \x01(\x08\x12\x17\n\x0finclude_ratings\x18\x07 \x01(\x08\x12O\n\x11include_tag_count\x18\x08 \x01(\x05\x42\x34\x82\xb5\x18\x30\x43ount of tags to return, as tagids.  Maximum 20.\x12\x17\n\x0finclude_reviews\x18\t \x01(\x08\x12P\n\x12include_basic_info\x18\n \x01(\x08\x42\x34\x82\xb5\x18\x30Include short description, publisher, developers\x12s\n\x1binclude_supported_languages\x18\x0b \x01(\x08\x42N\x82\xb5\x18Jincludes the games support for languages: supported, full_audio, subtitles\"\x93\x01\n\x1d\x43StoreBrowse_GetItems_Request\x12\x19\n\x03ids\x18\x01 \x03(\x0b\x32\x0c.StoreItemID\x12$\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x13.StoreBrowseContext\x12\x31\n\x0c\x64\x61ta_request\x18\x03 \x01(\x0b\x32\x1b.StoreBrowseItemDataRequest\"\xf8\x03\n\x0fStoreGameRating\x12%\n\x04type\x18\x01 \x01(\tB\x17\x82\xb5\x18\x13\'esrb\', \'pegi\', ...\x12\x35\n\x06rating\x18\x02 \x01(\tB%\x82\xb5\x18!\'t\' for teen, \'m\' for mature, ...\x12^\n\x0b\x64\x65scriptors\x18\x03 \x03(\tBI\x82\xb5\x18\x45\x41\x64\x64itional descriptors like \'Intense Violence\', \'Strong Language\',...\x12/\n\x14interactive_elements\x18\x04 \x01(\tB\x11\x82\xb5\x18\rESRB-specific\x12Q\n\x0crequired_age\x18\n \x01(\x05\x42;\x82\xb5\x18\x37\x41ge in years.  Store pages will prompt with an age gate\x12\x14\n\x0cuse_age_gate\x18\x0b \x01(\x08\x12<\n\timage_url\x18\x14 \x01(\tB)\x82\xb5\x18%An image corresponding to the rating.\x12O\n\x0cimage_target\x18\x15 \x01(\tB9\x82\xb5\x18\x35URL where the image should link for more information.\"\xbbK\n\tStoreItem\x12<\n\titem_type\x18\x01 \x01(\x0e\x32\x0f.EStoreItemType:\x18k_EStoreItemType_Invalid\x12\n\n\x02id\x18\x02 \x01(\r\x12\x32\n\x07success\x18\x03 \x01(\rB!\x82\xb5\x18\x1d\x45Result of this lookup action\x12\x0f\n\x07visible\x18\x04 \x01(\x08\x12}\n\"unvailable_for_country_restriction\x18\x05 \x01(\x08\x42Q\x82\xb5\x18MIndicates this app is visible in other regions, but not the requested reagion\x12\x0c\n\x04name\x18\x06 \x01(\t\x12`\n\x0estore_url_path\x18\x07 \x01(\tBH\x82\xb5\x18\x44The URL of this item\'s store page, to be appended to STORE_BASE_URL.\x12T\n\x05\x61ppid\x18\t \x01(\rBE\x82\xb5\x18\x41If this is an app, or a single-app package, the steamworks appid.\x12\xce\x01\n\x04type\x18\n \x01(\x0e\x32\x0e.EStoreAppType:\x14k_EStoreAppType_GameB\x99\x01\x82\xb5\x18\x94\x01Type of app (Game, Software, Music).  For packages/bundles, this will be the most interesting type (eg Game + Soundtrack bundle will have type Game)\x12]\n\x0eincluded_types\x18\x0b \x03(\x0e\x32\x0e.EStoreAppTypeB5\x82\xb5\x18\x31\x46or packages/bundles, all types of included items\x12\x46\n\x0fincluded_appids\x18\x0c \x03(\rB-\x82\xb5\x18)For packages/bundles, all included appids\x12\x0f\n\x07is_free\x18\r \x01(\x08\x12\x17\n\x0fis_early_access\x18\x0e \x01(\x08\x12.\n\rrelated_items\x18\x0f \x01(\x0b\x32\x17.StoreItem.RelatedItems\x12\x34\n\x15\x63ontent_descriptorids\x18\x14 \x03(\x0e\x32\x15.EContentDescriptorID\x12\x0e\n\x06tagids\x18\x15 \x03(\r\x12)\n\ncategories\x18\x16 \x01(\x0b\x32\x15.StoreItem.Categories\x12#\n\x07reviews\x18\x17 \x01(\x0b\x32\x12.StoreItem.Reviews\x12(\n\nbasic_info\x18\x18 \x01(\x0b\x32\x14.StoreItem.BasicInfo\x12\x1c\n\x04tags\x18\x19 \x03(\x0b\x32\x0e.StoreItem.Tag\x12!\n\x06\x61ssets\x18\x1e \x01(\x0b\x32\x11.StoreItem.Assets\x12\'\n\x07release\x18\x1f \x01(\x0b\x32\x16.StoreItem.ReleaseInfo\x12\'\n\tplatforms\x18  \x01(\x0b\x32\x14.StoreItem.Platforms\x12^\n\x0bgame_rating\x18! \x01(\x0b\x32\x10.StoreGameRatingB7\x82\xb5\x18\x33Local ratings agency information, like ESRB or PEGI\x12\x8c\x01\n\x14\x62\x65st_purchase_option\x18( \x01(\x0b\x32\x19.StoreItem.PurchaseOptionBS\x82\xb5\x18OThe cheapest way for the user to acquire this app or package (may be a bundle).\x12\xae\x01\n\x10purchase_options\x18) \x03(\x0b\x32\x19.StoreItem.PurchaseOptionBy\x82\xb5\x18uDifferent ways to buy this app or packages (packages can be purchased directly, but may also be included in bundles).\x12\x8b\x01\n\x0b\x61\x63\x63\x65ssories\x18* \x03(\x0b\x32\x19.StoreItem.PurchaseOptionB[\x82\xb5\x18WAdditional packages or bundles associated with an app, but that do not contain the app.\x12+\n\x0bscreenshots\x18\x32 \x01(\x0b\x32\x16.StoreItem.Screenshots\x12%\n\x08trailers\x18\x33 \x01(\x0b\x32\x13.StoreItem.Trailers\x12\x39\n\x13supported_languages\x18\x34 \x03(\x0b\x32\x1c.StoreItem.SupportedLanguage\x12\xde\x01\n\x17store_url_path_override\x18\x35 \x01(\tB\xbc\x01\x82\xb5\x18\xb7\x01Navigate to this URL (relative to store home) when the store capsule for this item is clicked, instead of the default /app/... URL. Used by advertising apps that point to a sale page.\x12Y\n\x0c\x66ree_weekend\x18\x36 \x01(\x0b\x32\x16.StoreItem.FreeWeekendB+\x82\xb5\x18\'Information about a free weekend offer.\x1aT\n\x0cRelatedItems\x12\x44\n\x0cparent_appid\x18\x01 \x01(\rB.\x82\xb5\x18*For DLC, Demos, etc, this is the main app.\x1a\xc6\x02\n\nCategories\x12Y\n\x1csupported_player_categoryids\x18\x02 \x03(\rB3\x82\xb5\x18/Categories like Single Player, Multiplayer, MMO\x12r\n\x13\x66\x65\x61ture_categoryids\x18\x03 \x03(\rBU\x82\xb5\x18QCategories indicating supported features like Steam Cloud, VAC, Achievements, etc\x12i\n\x16\x63ontroller_categoryids\x18\x04 \x03(\rBI\x82\xb5\x18\x45\x43\x61tegories indicating controller support and full controller support.\x1a\xc6\x04\n\x07Reviews\x12\xab\x01\n\x10summary_filtered\x18\x01 \x01(\x0b\x32%.StoreItem.Reviews.StoreReviewSummaryBj\x82\xb5\x18\x66Review summary with review bombs removed (if any).  Always present (if include_reviews set in request)\x12\x9a\x01\n\x12summary_unfiltered\x18\x02 \x01(\x0b\x32%.StoreItem.Reviews.StoreReviewSummaryBW\x82\xb5\x18SReview summary with review bombs included.  Only present if there are review bombs.\x1a\xef\x01\n\x12StoreReviewSummary\x12\x14\n\x0creview_count\x18\x01 \x01(\r\x12#\n\x10percent_positive\x18\x02 \x01(\x05\x42\t\x82\xb5\x18\x05\x30-100\x12@\n\x0creview_score\x18\x03 \x01(\x0e\x32\x11.EUserReviewScore:\x17k_EUserReviewScore_None\x12\\\n\x12review_score_label\x18\x04 \x01(\tB@\x82\xb5\x18<A string like \'Mixed\', \'Negative\', \'Overwhelmingly Positive\'\x1a\x8c\x04\n\tBasicInfo\x12\x19\n\x11short_description\x18\x01 \x01(\t\x12\x38\n\npublishers\x18\x02 \x03(\x0b\x32$.StoreItem.BasicInfo.CreatorHomeLink\x12\x38\n\ndevelopers\x18\x03 \x03(\x0b\x32$.StoreItem.BasicInfo.CreatorHomeLink\x12\x38\n\nfranchises\x18\x04 \x03(\x0b\x32$.StoreItem.BasicInfo.CreatorHomeLink\x12\x8c\x01\n\x10\x63\x61psule_headline\x18\x05 \x01(\tBr\x82\xb5\x18nA custom string specified by the partner for display on or around a capsule on the store, e.g. \'Just Updated!\'\x1a\xa6\x01\n\x0f\x43reatorHomeLink\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x84\x01\n\x17\x63reator_clan_account_id\x18\x02 \x01(\rBc\x82\xb5\x18_Optioanl field indicating this name is associated this the creator home via the clan account id\x1a$\n\x03Tag\x12\r\n\x05tagid\x18\x01 \x01(\r\x12\x0e\n\x06weight\x18\x02 \x01(\r\x1a\xf4\x06\n\x06\x41ssets\x12m\n\x10\x61sset_url_format\x18\x01 \x01(\tBS\x82\xb5\x18OFormat for URLs, should substitute the capsule name for ${FILENAME} in the URL.\x12\x14\n\x0cmain_capsule\x18\x02 \x01(\t\x12\x15\n\rsmall_capsule\x18\x03 \x01(\t\x12\x7f\n\x06header\x18\x04 \x01(\tBo\x82\xb5\x18kEquivalent to GetConstantRatioHeaderImage in PHP; apps will always have this, packages and bundles may not.\x12[\n\x0epackage_header\x18\x05 \x01(\tBC\x82\xb5\x18?A wider header used on package/bundle pages.  Not set for apps.\x12\x17\n\x0fpage_background\x18\x06 \x01(\t\x12!\n\x0chero_capsule\x18\x07 \x01(\tB\x0b\x82\xb5\x18\x07\x33\x37\x34x448\x12=\n\x0fhero_capsule_2x\x18\x08 \x01(\tB$\x82\xb5\x18 748x896 version of hero capsule.\x12\x39\n\x0flibrary_capsule\x18\t \x01(\tB \x82\xb5\x18\x1c\x33\x30\x30x450 - tall library asset\x12<\n\x12library_capsule_2x\x18\n \x01(\tB \x82\xb5\x18\x1c\x36\x30\x30x900 - tall library asset\x12O\n\x0clibrary_hero\x18\x0b \x01(\tB9\x82\xb5\x18\x35\x39\x36\x30x310 or 1920x620 - library detail background asset\x12T\n\x0flibrary_hero_2x\x18\x0c \x01(\tB;\x82\xb5\x18\x37\x31\x39\x32\x30x620 or 3840x1240 - library detail background asset\x12U\n\x0e\x63ommunity_icon\x18\r \x01(\tB=\x82\xb5\x18\x39\x33\x32x32 jpg uploading via steamworks under community assets\x1a\xc2\x08\n\x0bReleaseInfo\x12\x90\x01\n\x12steam_release_date\x18\x01 \x01(\rBt\x82\xb5\x18pThe date this item first released on the Steam store.  For Early Access graduates, this is their graduation day.\x12w\n\x15original_release_date\x18\x02 \x01(\rBX\x82\xb5\x18TOptional; the date this item first released elsewhere, typically back catalog items.\x12o\n\x1boriginal_steam_release_date\x18\x03 \x01(\rBJ\x82\xb5\x18\x46\x46or Early Access graduates, the date the game first appeared on Steam.\x12\x88\x01\n\x0eis_coming_soon\x18\x04 \x01(\x08\x42p\x82\xb5\x18lIs the app coming soon?  This flag should be preferred to doing time comparisons against steam_release_date.\x12V\n\nis_preload\x18\x05 \x01(\x08\x42\x42\x82\xb5\x18>Can the app be preloaded?  Only applies to Coming Soon titles.\x12v\n\x1b\x63ustom_release_date_message\x18\x06 \x01(\tBQ\x82\xb5\x18MCustom release date string.  steam_release_date will be unset if this is set.\x12\x8c\x01\n\x18is_abridged_release_date\x18\x07 \x01(\x08\x42j\x82\xb5\x18\x66Release date should be displayed as month-year only.  steam_release_date is the last day of the month.\x12}\n\x13\x63oming_soon_display\x18\x08 \x01(\tB`\x82\xb5\x18\\One of \'date_full\', \'date_month\', \'date_quarter\', \'date_year\', \'text_comingsoon\', \'text_tba\'\x12\x17\n\x0fis_early_access\x18\n \x01(\x08\x12\x18\n\x10mac_release_date\x18\x14 \x01(\r\x12\x1a\n\x12linux_release_date\x18\x15 \x01(\r\x1a\xe5\x02\n\tPlatforms\x12\x0f\n\x07windows\x18\x01 \x01(\x08\x12\x0b\n\x03mac\x18\x02 \x01(\x08\x12\x15\n\rsteamos_linux\x18\x03 \x01(\x08\x12\x32\n\nvr_support\x18\n \x01(\x0b\x32\x1e.StoreItem.Platforms.VRSupport\x12o\n\x1asteam_deck_compat_category\x18\x0b \x01(\x0e\x32 .ESteamDeckCompatibilityCategory:)k_ESteamDeckCompatibilityCategory_Unknown\x1a~\n\tVRSupport\x12\r\n\x05vrhmd\x18\x01 \x01(\x08\x12\x12\n\nvrhmd_only\x18\x02 \x01(\x08\x12\x10\n\x08htc_vive\x18( \x01(\x08\x12\x13\n\x0boculus_rift\x18) \x01(\x08\x12\x12\n\nwindows_mr\x18* \x01(\x08\x12\x13\n\x0bvalve_index\x18+ \x01(\x08\x1a\xf6\x0b\n\x0ePurchaseOption\x12\x11\n\tpackageid\x18\x01 \x01(\x05\x12\x10\n\x08\x62undleid\x18\x02 \x01(\x05\x12\x43\n\x14purchase_option_name\x18\x03 \x01(\tB%\x82\xb5\x18!The name of the package or bundle\x12\x63\n\x14\x66inal_price_in_cents\x18\x05 \x01(\x03\x42\x45\x82\xb5\x18\x41\x41lways set.  Includes any applicable non user-specific discounts.\x12\x63\n\x17original_price_in_cents\x18\x06 \x01(\x03\x42\x42\x82\xb5\x18>If discounted, this is the price the item would normally cost.\x12!\n\x19user_final_price_in_cents\x18\x07 \x01(\x03\x12j\n\x15\x66ormatted_final_price\x18\x08 \x01(\tBK\x82\xb5\x18GAlways set.  Formatted with currency symbol and decimal, like \'$10.00\'.\x12 \n\x18\x66ormatted_original_price\x18\t \x01(\t\x12X\n\x0c\x64iscount_pct\x18\n \x01(\x05\x42\x42\x82\xb5\x18>If discounted, calculated from final price and original price.\x12\x19\n\x11user_discount_pct\x18\x0b \x01(\x05\x12\xae\x01\n\x13\x62undle_discount_pct\x18\x0c \x01(\x05\x42\x90\x01\x82\xb5\x18\x8b\x01If this is a bundle, the savings from buying the bundle.  If no bundle items are on active discount, this will be the same as discount_pct.\x12r\n\x10\x61\x63tive_discounts\x18\x14 \x03(\x0b\x32\".StoreItem.PurchaseOption.DiscountB4\x82\xb5\x18\x30\x44iscounts included in discounted_price_in_cents.\x12\x87\x01\n\x15user_active_discounts\x18\x15 \x03(\x0b\x32\".StoreItem.PurchaseOption.DiscountBD\x82\xb5\x18@Additional discounts included in user_discounted_price_in_cents.\x12\x8d\x01\n\x12inactive_discounts\x18\x16 \x03(\x0b\x32\".StoreItem.PurchaseOption.DiscountBM\x82\xb5\x18IAdditional user-specific discounts that do not apply to the current user.\x12\x19\n\x11user_can_purchase\x18\x1e \x01(\x08\x12!\n\x19user_can_purchase_as_gift\x18\x1f \x01(\x08\x12?\n\x15is_commercial_license\x18( \x01(\x08\x42 \x82\xb5\x18\x1cThis is a commercial license\x12n\n\x1cshould_suppress_discount_pct\x18) \x01(\x08\x42H\x82\xb5\x18\x44\x44on\'t show the discount percentage on a store capsule for this item.\x1a\\\n\x08\x44iscount\x12\x17\n\x0f\x64iscount_amount\x18\x01 \x01(\x03\x12\x1c\n\x14\x64iscount_description\x18\x02 \x01(\t\x12\x19\n\x11\x64iscount_end_date\x18\x03 \x01(\r\x1a\xf9\x04\n\x0bScreenshots\x12g\n\x14\x61ll_ages_screenshots\x18\x02 \x03(\x0b\x32!.StoreItem.Screenshots.ScreenshotB&\x82\xb5\x18\"Screenshots suitable for all ages.\x12\xb2\x01\n\x1amature_content_screenshots\x18\x03 \x03(\x0b\x32!.StoreItem.Screenshots.ScreenshotBk\x82\xb5\x18gScreenshots that may contain mature content; these should only be shown after verifying age (age gate).\x1a\xcb\x02\n\nScreenshot\x12\x83\x01\n\x08\x66ilename\x18\x01 \x01(\tBq\x82\xb5\x18mPath to file on media CDN.  Can access sized version by appending to SHA: \'.1920x1080\', \'.600x338\', \'.116x65\'\x12\xb6\x01\n\x07ordinal\x18\x02 \x01(\x05\x42\xa4\x01\x82\xb5\x18\x9f\x01Screenshots should be displayed in order of ascending ordinal; they are returned in-order but client may need to merge all_ages and mature_content_screenshots.\x1a\xd4\x07\n\x08Trailers\x12R\n\nhighlights\x18\x01 \x03(\x0b\x32\x1b.StoreItem.Trailers.TrailerB!\x82\xb5\x18\x1dPrimary trailers for this app\x12\x9a\x01\n\x0eother_trailers\x18\x02 \x03(\x0b\x32\x1b.StoreItem.Trailers.TrailerBe\x82\xb5\x18\x61\x41\x64\x64itional trailers; on the app page, these are shown after screenshots (highlights shown before)\x1a\xa8\x01\n\x0bVideoSource\x12\x38\n\x08\x66ilename\x18\x01 \x01(\tB&\x82\xb5\x18\"Substitute into trailer_url_format\x12_\n\x04type\x18\x02 \x01(\tBQ\x82\xb5\x18M\'video/webm\' or \'video/mp4\'; can just put this directly in to a <source> tag.\x1a\xab\x04\n\x07Trailer\x12\x14\n\x0ctrailer_name\x18\x01 \x01(\t\x12g\n\x12trailer_url_format\x18\x02 \x01(\tBK\x82\xb5\x18GFormat for URLs, should substitute filename for ${FILENAME} in the URL.\x12\x35\n\x0ctrailer_480p\x18\x03 \x03(\x0b\x32\x1f.StoreItem.Trailers.VideoSource\x12\x34\n\x0btrailer_max\x18\x04 \x03(\x0b\x32\x1f.StoreItem.Trailers.VideoSource\x12\x35\n\x0cmicrotrailer\x18\x05 \x03(\x0b\x32\x1f.StoreItem.Trailers.VideoSource\x12\x42\n\x11screenshot_medium\x18\n \x01(\tB\'\x82\xb5\x18#293x165px.  Use trailer_url_format.\x12O\n\x0fscreenshot_full\x18\x0b \x01(\tB6\x82\xb5\x18\x32Same size as trailer_max.  Use trailer_url_format.\x12h\n\x0ftrailer_base_id\x18\x0c \x01(\x05\x42O\x82\xb5\x18KTrailer ID.  For localized trailers, this will be the original trailer\'s ID\x1ao\n\x11SupportedLanguage\x12 \n\telanguage\x18\x01 \x01(\x05\x42\r\x82\xb5\x18\tELanguage\x12\x11\n\tsupported\x18\x02 \x01(\x08\x12\x12\n\nfull_audio\x18\x03 \x01(\x08\x12\x11\n\tsubtitles\x18\x04 \x01(\x08\x1a\xbd\x01\n\x0b\x46reeWeekend\x12\x35\n\nstart_time\x18\x01 \x01(\rB!\x82\xb5\x18\x1dWhen the free weekend starts.\x12\x31\n\x08\x65nd_time\x18\x02 \x01(\rB\x1f\x82\xb5\x18\x1bWhen the free weekend ends.\x12\x44\n\x04text\x18\x03 \x01(\tB6\x82\xb5\x18\x32Text to show as a description of the free weekend.\"A\n\x1e\x43StoreBrowse_GetItems_Response\x12\x1f\n\x0bstore_items\x18\x01 \x03(\x0b\x32\n.StoreItem\"a\n\'CStoreBrowse_GetStoreCategories_Request\x12\x10\n\x08language\x18\x01 \x01(\t\x12$\n\telanguage\x18\x02 \x01(\x05:\x02-1B\r\x82\xb5\x18\tELanguage\"\xa1\x03\n(CStoreBrowse_GetStoreCategories_Response\x12\x46\n\ncategories\x18\x01 \x03(\x0b\x32\x32.CStoreBrowse_GetStoreCategories_Response.Category\x1a\xac\x02\n\x08\x43\x61tegory\x12\x12\n\ncategoryid\x18\x01 \x01(\r\x12@\n\x04type\x18\x02 \x01(\x0e\x32\x13.EStoreCategoryType:\x1dk_EStoreCategoryType_Category\x12\x15\n\rinternal_name\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12.\n\timage_url\x18\x05 \x01(\tB\x1b\x82\xb5\x18\x17\x41ppend to STORE_CDN_URL\x12m\n\x0eshow_in_search\x18\x06 \x01(\x08\x42U\x82\xb5\x18QIndicates this category can link to search results showing all items in category.*\xa6\x01\n\x0e\x45StoreItemType\x12%\n\x18k_EStoreItemType_Invalid\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x18\n\x14k_EStoreItemType_App\x10\x00\x12\x1c\n\x18k_EStoreItemType_Package\x10\x01\x12\x1b\n\x17k_EStoreItemType_Bundle\x10\x02\x12\x18\n\x14k_EStoreItemType_Mtx\x10\x03*\xab\x03\n\rEStoreAppType\x12\x18\n\x14k_EStoreAppType_Game\x10\x00\x12\x18\n\x14k_EStoreAppType_Demo\x10\x01\x12\x17\n\x13k_EStoreAppType_Mod\x10\x02\x12\x19\n\x15k_EStoreAppType_Movie\x10\x03\x12\x17\n\x13k_EStoreAppType_DLC\x10\x04\x12\x19\n\x15k_EStoreAppType_Guide\x10\x05\x12\x1c\n\x18k_EStoreAppType_Software\x10\x06\x12\x19\n\x15k_EStoreAppType_Video\x10\x07\x12\x1a\n\x16k_EStoreAppType_Series\x10\x08\x12\x1b\n\x17k_EStoreAppType_Episode\x10\t\x12\x1c\n\x18k_EStoreAppType_Hardware\x10\n\x12\x19\n\x15k_EStoreAppType_Music\x10\x0b\x12\x18\n\x14k_EStoreAppType_Beta\x10\x0c\x12\x18\n\x14k_EStoreAppType_Tool\x10\r\x12\x1f\n\x1bk_EStoreAppType_Advertising\x10\x0e*\x85\x03\n\x10\x45UserReviewScore\x12\x1b\n\x17k_EUserReviewScore_None\x10\x00\x12-\n)k_EUserReviewScore_OverwhelminglyNegative\x10\x01\x12#\n\x1fk_EUserReviewScore_VeryNegative\x10\x02\x12\x1f\n\x1bk_EUserReviewScore_Negative\x10\x03\x12%\n!k_EUserReviewScore_MostlyNegative\x10\x04\x12\x1c\n\x18k_EUserReviewScore_Mixed\x10\x05\x12%\n!k_EUserReviewScore_MostlyPositive\x10\x06\x12\x1f\n\x1bk_EUserReviewScore_Positive\x10\x07\x12#\n\x1fk_EUserReviewScore_VeryPositive\x10\x08\x12-\n)k_EUserReviewScore_OverwhelminglyPositive\x10\t*\xf4\x01\n\x12\x45StoreCategoryType\x12!\n\x1dk_EStoreCategoryType_Category\x10\x00\x12)\n%k_EStoreCategoryType_SupportedPlayers\x10\x01\x12 \n\x1ck_EStoreCategoryType_Feature\x10\x02\x12*\n&k_EStoreCategoryType_ControllerSupport\x10\x03\x12$\n k_EStoreCategoryType_CloudGaming\x10\x04\x12\x1c\n\x18k_EStoreCategoryType_MAX\x10\x05\x32\xab\x03\n\x0bStoreBrowse\x12y\n\x08GetItems\x12\x1e.CStoreBrowse_GetItems_Request\x1a\x1f.CStoreBrowse_GetItems_Response\",\x82\xb5\x18(Get information about items on the store\x12\xf8\x01\n\x12GetStoreCategories\x12(.CStoreBrowse_GetStoreCategories_Request\x1a).CStoreBrowse_GetStoreCategories_Response\"\x8c\x01\x82\xb5\x18\x87\x01Get category definitions for store.  This is a public-facing API (as compared to StoreCatalog.GetCategories, which is intended for PHP)\x1a&\x82\xb5\x18\"APIs for accessing store item dataB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,enums__productinfo__pb2.DESCRIPTOR,enums__pb2.DESCRIPTOR,])

_ESTOREITEMTYPE = _descriptor.EnumDescriptor(
  name='EStoreItemType',
  full_name='EStoreItemType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStoreItemType_Invalid', index=0, number=-1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreItemType_App', index=1, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreItemType_Package', index=2, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreItemType_Bundle', index=3, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreItemType_Mtx', index=4, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11811,
  serialized_end=11977,
)
_sym_db.RegisterEnumDescriptor(_ESTOREITEMTYPE)

EStoreItemType = enum_type_wrapper.EnumTypeWrapper(_ESTOREITEMTYPE)
_ESTOREAPPTYPE = _descriptor.EnumDescriptor(
  name='EStoreAppType',
  full_name='EStoreAppType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_Game', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_Demo', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_Mod', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_Movie', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_DLC', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_Guide', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_Software', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_Video', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_Series', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_Episode', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_Hardware', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_Music', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_Beta', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_Tool', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreAppType_Advertising', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11980,
  serialized_end=12407,
)
_sym_db.RegisterEnumDescriptor(_ESTOREAPPTYPE)

EStoreAppType = enum_type_wrapper.EnumTypeWrapper(_ESTOREAPPTYPE)
_EUSERREVIEWSCORE = _descriptor.EnumDescriptor(
  name='EUserReviewScore',
  full_name='EUserReviewScore',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScore_None', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScore_OverwhelminglyNegative', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScore_VeryNegative', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScore_Negative', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScore_MostlyNegative', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScore_Mixed', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScore_MostlyPositive', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScore_Positive', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScore_VeryPositive', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScore_OverwhelminglyPositive', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12410,
  serialized_end=12799,
)
_sym_db.RegisterEnumDescriptor(_EUSERREVIEWSCORE)

EUserReviewScore = enum_type_wrapper.EnumTypeWrapper(_EUSERREVIEWSCORE)
_ESTORECATEGORYTYPE = _descriptor.EnumDescriptor(
  name='EStoreCategoryType',
  full_name='EStoreCategoryType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStoreCategoryType_Category', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreCategoryType_SupportedPlayers', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreCategoryType_Feature', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreCategoryType_ControllerSupport', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreCategoryType_CloudGaming', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStoreCategoryType_MAX', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12802,
  serialized_end=13046,
)
_sym_db.RegisterEnumDescriptor(_ESTORECATEGORYTYPE)

EStoreCategoryType = enum_type_wrapper.EnumTypeWrapper(_ESTORECATEGORYTYPE)
k_EStoreItemType_Invalid = -1
k_EStoreItemType_App = 0
k_EStoreItemType_Package = 1
k_EStoreItemType_Bundle = 2
k_EStoreItemType_Mtx = 3
k_EStoreAppType_Game = 0
k_EStoreAppType_Demo = 1
k_EStoreAppType_Mod = 2
k_EStoreAppType_Movie = 3
k_EStoreAppType_DLC = 4
k_EStoreAppType_Guide = 5
k_EStoreAppType_Software = 6
k_EStoreAppType_Video = 7
k_EStoreAppType_Series = 8
k_EStoreAppType_Episode = 9
k_EStoreAppType_Hardware = 10
k_EStoreAppType_Music = 11
k_EStoreAppType_Beta = 12
k_EStoreAppType_Tool = 13
k_EStoreAppType_Advertising = 14
k_EUserReviewScore_None = 0
k_EUserReviewScore_OverwhelminglyNegative = 1
k_EUserReviewScore_VeryNegative = 2
k_EUserReviewScore_Negative = 3
k_EUserReviewScore_MostlyNegative = 4
k_EUserReviewScore_Mixed = 5
k_EUserReviewScore_MostlyPositive = 6
k_EUserReviewScore_Positive = 7
k_EUserReviewScore_VeryPositive = 8
k_EUserReviewScore_OverwhelminglyPositive = 9
k_EStoreCategoryType_Category = 0
k_EStoreCategoryType_SupportedPlayers = 1
k_EStoreCategoryType_Feature = 2
k_EStoreCategoryType_ControllerSupport = 3
k_EStoreCategoryType_CloudGaming = 4
k_EStoreCategoryType_MAX = 5



_STOREITEMID = _descriptor.Descriptor(
  name='StoreItemID',
  full_name='StoreItemID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='StoreItemID.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packageid', full_name='StoreItemID.packageid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bundleid', full_name='StoreItemID.bundleid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=198,
)


_STOREBROWSECONTEXT = _descriptor.Descriptor(
  name='StoreBrowseContext',
  full_name='StoreBrowseContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='StoreBrowseContext.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elanguage', full_name='StoreBrowseContext.elanguage', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\tELanguage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='StoreBrowseContext.country_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"2-character country code; required', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_realm', full_name='StoreBrowseContext.steam_realm', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\013ESteamRealm', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=373,
)


_STOREBROWSEITEMDATAREQUEST = _descriptor.Descriptor(
  name='StoreBrowseItemDataRequest',
  full_name='StoreBrowseItemDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='include_assets', full_name='StoreBrowseItemDataRequest.include_assets', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_release', full_name='StoreBrowseItemDataRequest.include_release', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_platforms', full_name='StoreBrowseItemDataRequest.include_platforms', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_all_purchase_options', full_name='StoreBrowseItemDataRequest.include_all_purchase_options', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_screenshots', full_name='StoreBrowseItemDataRequest.include_screenshots', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_trailers', full_name='StoreBrowseItemDataRequest.include_trailers', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_ratings', full_name='StoreBrowseItemDataRequest.include_ratings', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_tag_count', full_name='StoreBrowseItemDataRequest.include_tag_count', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0300Count of tags to return, as tagids.  Maximum 20.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_reviews', full_name='StoreBrowseItemDataRequest.include_reviews', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_basic_info', full_name='StoreBrowseItemDataRequest.include_basic_info', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0300Include short description, publisher, developers', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_supported_languages', full_name='StoreBrowseItemDataRequest.include_supported_languages', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030Jincludes the games support for languages: supported, full_audio, subtitles', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=903,
)


_CSTOREBROWSE_GETITEMS_REQUEST = _descriptor.Descriptor(
  name='CStoreBrowse_GetItems_Request',
  full_name='CStoreBrowse_GetItems_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='CStoreBrowse_GetItems_Request.ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='context', full_name='CStoreBrowse_GetItems_Request.context', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_request', full_name='CStoreBrowse_GetItems_Request.data_request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=906,
  serialized_end=1053,
)


_STOREGAMERATING = _descriptor.Descriptor(
  name='StoreGameRating',
  full_name='StoreGameRating',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='StoreGameRating.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023\'esrb\', \'pegi\', ...', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rating', full_name='StoreGameRating.rating', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!\'t\' for teen, \'m\' for mature, ...', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='descriptors', full_name='StoreGameRating.descriptors', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030EAdditional descriptors like \'Intense Violence\', \'Strong Language\',...', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interactive_elements', full_name='StoreGameRating.interactive_elements', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\rESRB-specific', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_age', full_name='StoreGameRating.required_age', index=4,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0307Age in years.  Store pages will prompt with an age gate', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_age_gate', full_name='StoreGameRating.use_age_gate', index=5,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_url', full_name='StoreGameRating.image_url', index=6,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%An image corresponding to the rating.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_target', full_name='StoreGameRating.image_target', index=7,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0305URL where the image should link for more information.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1056,
  serialized_end=1560,
)


_STOREITEM_RELATEDITEMS = _descriptor.Descriptor(
  name='RelatedItems',
  full_name='StoreItem.RelatedItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_appid', full_name='StoreItem.RelatedItems.parent_appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030*For DLC, Demos, etc, this is the main app.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3866,
  serialized_end=3950,
)

_STOREITEM_CATEGORIES = _descriptor.Descriptor(
  name='Categories',
  full_name='StoreItem.Categories',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='supported_player_categoryids', full_name='StoreItem.Categories.supported_player_categoryids', index=0,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030/Categories like Single Player, Multiplayer, MMO', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_categoryids', full_name='StoreItem.Categories.feature_categoryids', index=1,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030QCategories indicating supported features like Steam Cloud, VAC, Achievements, etc', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_categoryids', full_name='StoreItem.Categories.controller_categoryids', index=2,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030ECategories indicating controller support and full controller support.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3953,
  serialized_end=4279,
)

_STOREITEM_REVIEWS_STOREREVIEWSUMMARY = _descriptor.Descriptor(
  name='StoreReviewSummary',
  full_name='StoreItem.Reviews.StoreReviewSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='review_count', full_name='StoreItem.Reviews.StoreReviewSummary.review_count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percent_positive', full_name='StoreItem.Reviews.StoreReviewSummary.percent_positive', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='review_score', full_name='StoreItem.Reviews.StoreReviewSummary.review_score', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='review_score_label', full_name='StoreItem.Reviews.StoreReviewSummary.review_score_label', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030<A string like \'Mixed\', \'Negative\', \'Overwhelmingly Positive\'', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4625,
  serialized_end=4864,
)

_STOREITEM_REVIEWS = _descriptor.Descriptor(
  name='Reviews',
  full_name='StoreItem.Reviews',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='summary_filtered', full_name='StoreItem.Reviews.summary_filtered', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030fReview summary with review bombs removed (if any).  Always present (if include_reviews set in request)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary_unfiltered', full_name='StoreItem.Reviews.summary_unfiltered', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030SReview summary with review bombs included.  Only present if there are review bombs.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STOREITEM_REVIEWS_STOREREVIEWSUMMARY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4282,
  serialized_end=4864,
)

_STOREITEM_BASICINFO_CREATORHOMELINK = _descriptor.Descriptor(
  name='CreatorHomeLink',
  full_name='StoreItem.BasicInfo.CreatorHomeLink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='StoreItem.BasicInfo.CreatorHomeLink.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_clan_account_id', full_name='StoreItem.BasicInfo.CreatorHomeLink.creator_clan_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030_Optioanl field indicating this name is associated this the creator home via the clan account id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5225,
  serialized_end=5391,
)

_STOREITEM_BASICINFO = _descriptor.Descriptor(
  name='BasicInfo',
  full_name='StoreItem.BasicInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='short_description', full_name='StoreItem.BasicInfo.short_description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishers', full_name='StoreItem.BasicInfo.publishers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='developers', full_name='StoreItem.BasicInfo.developers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='franchises', full_name='StoreItem.BasicInfo.franchises', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capsule_headline', full_name='StoreItem.BasicInfo.capsule_headline', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030nA custom string specified by the partner for display on or around a capsule on the store, e.g. \'Just Updated!\'', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STOREITEM_BASICINFO_CREATORHOMELINK, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4867,
  serialized_end=5391,
)

_STOREITEM_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='StoreItem.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tagid', full_name='StoreItem.Tag.tagid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='StoreItem.Tag.weight', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5393,
  serialized_end=5429,
)

_STOREITEM_ASSETS = _descriptor.Descriptor(
  name='Assets',
  full_name='StoreItem.Assets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset_url_format', full_name='StoreItem.Assets.asset_url_format', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030OFormat for URLs, should substitute the capsule name for ${FILENAME} in the URL.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_capsule', full_name='StoreItem.Assets.main_capsule', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='small_capsule', full_name='StoreItem.Assets.small_capsule', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='StoreItem.Assets.header', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030kEquivalent to GetConstantRatioHeaderImage in PHP; apps will always have this, packages and bundles may not.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='package_header', full_name='StoreItem.Assets.package_header', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030?A wider header used on package/bundle pages.  Not set for apps.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_background', full_name='StoreItem.Assets.page_background', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hero_capsule', full_name='StoreItem.Assets.hero_capsule', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\007374x448', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hero_capsule_2x', full_name='StoreItem.Assets.hero_capsule_2x', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030 748x896 version of hero capsule.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='library_capsule', full_name='StoreItem.Assets.library_capsule', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034300x450 - tall library asset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='library_capsule_2x', full_name='StoreItem.Assets.library_capsule_2x', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034600x900 - tall library asset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='library_hero', full_name='StoreItem.Assets.library_hero', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0305960x310 or 1920x620 - library detail background asset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='library_hero_2x', full_name='StoreItem.Assets.library_hero_2x', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\03071920x620 or 3840x1240 - library detail background asset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='community_icon', full_name='StoreItem.Assets.community_icon', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030932x32 jpg uploading via steamworks under community assets', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5432,
  serialized_end=6316,
)

_STOREITEM_RELEASEINFO = _descriptor.Descriptor(
  name='ReleaseInfo',
  full_name='StoreItem.ReleaseInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_release_date', full_name='StoreItem.ReleaseInfo.steam_release_date', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030pThe date this item first released on the Steam store.  For Early Access graduates, this is their graduation day.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='original_release_date', full_name='StoreItem.ReleaseInfo.original_release_date', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030TOptional; the date this item first released elsewhere, typically back catalog items.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='original_steam_release_date', full_name='StoreItem.ReleaseInfo.original_steam_release_date', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030FFor Early Access graduates, the date the game first appeared on Steam.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_coming_soon', full_name='StoreItem.ReleaseInfo.is_coming_soon', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030lIs the app coming soon?  This flag should be preferred to doing time comparisons against steam_release_date.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_preload', full_name='StoreItem.ReleaseInfo.is_preload', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030>Can the app be preloaded?  Only applies to Coming Soon titles.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_release_date_message', full_name='StoreItem.ReleaseInfo.custom_release_date_message', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030MCustom release date string.  steam_release_date will be unset if this is set.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_abridged_release_date', full_name='StoreItem.ReleaseInfo.is_abridged_release_date', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030fRelease date should be displayed as month-year only.  steam_release_date is the last day of the month.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coming_soon_display', full_name='StoreItem.ReleaseInfo.coming_soon_display', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\\One of \'date_full\', \'date_month\', \'date_quarter\', \'date_year\', \'text_comingsoon\', \'text_tba\'', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_early_access', full_name='StoreItem.ReleaseInfo.is_early_access', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac_release_date', full_name='StoreItem.ReleaseInfo.mac_release_date', index=9,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linux_release_date', full_name='StoreItem.ReleaseInfo.linux_release_date', index=10,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6319,
  serialized_end=7409,
)

_STOREITEM_PLATFORMS_VRSUPPORT = _descriptor.Descriptor(
  name='VRSupport',
  full_name='StoreItem.Platforms.VRSupport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vrhmd', full_name='StoreItem.Platforms.VRSupport.vrhmd', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vrhmd_only', full_name='StoreItem.Platforms.VRSupport.vrhmd_only', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='htc_vive', full_name='StoreItem.Platforms.VRSupport.htc_vive', index=2,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oculus_rift', full_name='StoreItem.Platforms.VRSupport.oculus_rift', index=3,
      number=41, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='windows_mr', full_name='StoreItem.Platforms.VRSupport.windows_mr', index=4,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valve_index', full_name='StoreItem.Platforms.VRSupport.valve_index', index=5,
      number=43, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7643,
  serialized_end=7769,
)

_STOREITEM_PLATFORMS = _descriptor.Descriptor(
  name='Platforms',
  full_name='StoreItem.Platforms',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='windows', full_name='StoreItem.Platforms.windows', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac', full_name='StoreItem.Platforms.mac', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamos_linux', full_name='StoreItem.Platforms.steamos_linux', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vr_support', full_name='StoreItem.Platforms.vr_support', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_deck_compat_category', full_name='StoreItem.Platforms.steam_deck_compat_category', index=4,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STOREITEM_PLATFORMS_VRSUPPORT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7412,
  serialized_end=7769,
)

_STOREITEM_PURCHASEOPTION_DISCOUNT = _descriptor.Descriptor(
  name='Discount',
  full_name='StoreItem.PurchaseOption.Discount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='discount_amount', full_name='StoreItem.PurchaseOption.Discount.discount_amount', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discount_description', full_name='StoreItem.PurchaseOption.Discount.discount_description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discount_end_date', full_name='StoreItem.PurchaseOption.Discount.discount_end_date', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9206,
  serialized_end=9298,
)

_STOREITEM_PURCHASEOPTION = _descriptor.Descriptor(
  name='PurchaseOption',
  full_name='StoreItem.PurchaseOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='packageid', full_name='StoreItem.PurchaseOption.packageid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bundleid', full_name='StoreItem.PurchaseOption.bundleid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purchase_option_name', full_name='StoreItem.PurchaseOption.purchase_option_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!The name of the package or bundle', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='final_price_in_cents', full_name='StoreItem.PurchaseOption.final_price_in_cents', index=3,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030AAlways set.  Includes any applicable non user-specific discounts.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='original_price_in_cents', full_name='StoreItem.PurchaseOption.original_price_in_cents', index=4,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030>If discounted, this is the price the item would normally cost.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_final_price_in_cents', full_name='StoreItem.PurchaseOption.user_final_price_in_cents', index=5,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='formatted_final_price', full_name='StoreItem.PurchaseOption.formatted_final_price', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030GAlways set.  Formatted with currency symbol and decimal, like \'$10.00\'.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='formatted_original_price', full_name='StoreItem.PurchaseOption.formatted_original_price', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discount_pct', full_name='StoreItem.PurchaseOption.discount_pct', index=8,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030>If discounted, calculated from final price and original price.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_discount_pct', full_name='StoreItem.PurchaseOption.user_discount_pct', index=9,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bundle_discount_pct', full_name='StoreItem.PurchaseOption.bundle_discount_pct', index=10,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\213\001If this is a bundle, the savings from buying the bundle.  If no bundle items are on active discount, this will be the same as discount_pct.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_discounts', full_name='StoreItem.PurchaseOption.active_discounts', index=11,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0300Discounts included in discounted_price_in_cents.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_active_discounts', full_name='StoreItem.PurchaseOption.user_active_discounts', index=12,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030@Additional discounts included in user_discounted_price_in_cents.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inactive_discounts', full_name='StoreItem.PurchaseOption.inactive_discounts', index=13,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030IAdditional user-specific discounts that do not apply to the current user.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_can_purchase', full_name='StoreItem.PurchaseOption.user_can_purchase', index=14,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_can_purchase_as_gift', full_name='StoreItem.PurchaseOption.user_can_purchase_as_gift', index=15,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_commercial_license', full_name='StoreItem.PurchaseOption.is_commercial_license', index=16,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034This is a commercial license', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='should_suppress_discount_pct', full_name='StoreItem.PurchaseOption.should_suppress_discount_pct', index=17,
      number=41, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030DDon\'t show the discount percentage on a store capsule for this item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STOREITEM_PURCHASEOPTION_DISCOUNT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7772,
  serialized_end=9298,
)

_STOREITEM_SCREENSHOTS_SCREENSHOT = _descriptor.Descriptor(
  name='Screenshot',
  full_name='StoreItem.Screenshots.Screenshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='StoreItem.Screenshots.Screenshot.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030mPath to file on media CDN.  Can access sized version by appending to SHA: \'.1920x1080\', \'.600x338\', \'.116x65\'', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='StoreItem.Screenshots.Screenshot.ordinal', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\237\001Screenshots should be displayed in order of ascending ordinal; they are returned in-order but client may need to merge all_ages and mature_content_screenshots.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9603,
  serialized_end=9934,
)

_STOREITEM_SCREENSHOTS = _descriptor.Descriptor(
  name='Screenshots',
  full_name='StoreItem.Screenshots',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='all_ages_screenshots', full_name='StoreItem.Screenshots.all_ages_screenshots', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"Screenshots suitable for all ages.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mature_content_screenshots', full_name='StoreItem.Screenshots.mature_content_screenshots', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030gScreenshots that may contain mature content; these should only be shown after verifying age (age gate).', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STOREITEM_SCREENSHOTS_SCREENSHOT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9301,
  serialized_end=9934,
)

_STOREITEM_TRAILERS_VIDEOSOURCE = _descriptor.Descriptor(
  name='VideoSource',
  full_name='StoreItem.Trailers.VideoSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='StoreItem.Trailers.VideoSource.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"Substitute into trailer_url_format', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='StoreItem.Trailers.VideoSource.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030M\'video/webm\' or \'video/mp4\'; can just put this directly in to a <source> tag.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10191,
  serialized_end=10359,
)

_STOREITEM_TRAILERS_TRAILER = _descriptor.Descriptor(
  name='Trailer',
  full_name='StoreItem.Trailers.Trailer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trailer_name', full_name='StoreItem.Trailers.Trailer.trailer_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trailer_url_format', full_name='StoreItem.Trailers.Trailer.trailer_url_format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030GFormat for URLs, should substitute filename for ${FILENAME} in the URL.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trailer_480p', full_name='StoreItem.Trailers.Trailer.trailer_480p', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trailer_max', full_name='StoreItem.Trailers.Trailer.trailer_max', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='microtrailer', full_name='StoreItem.Trailers.Trailer.microtrailer', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='screenshot_medium', full_name='StoreItem.Trailers.Trailer.screenshot_medium', index=5,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030#293x165px.  Use trailer_url_format.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='screenshot_full', full_name='StoreItem.Trailers.Trailer.screenshot_full', index=6,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302Same size as trailer_max.  Use trailer_url_format.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trailer_base_id', full_name='StoreItem.Trailers.Trailer.trailer_base_id', index=7,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030KTrailer ID.  For localized trailers, this will be the original trailer\'s ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10362,
  serialized_end=10917,
)

_STOREITEM_TRAILERS = _descriptor.Descriptor(
  name='Trailers',
  full_name='StoreItem.Trailers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='highlights', full_name='StoreItem.Trailers.highlights', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035Primary trailers for this app', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_trailers', full_name='StoreItem.Trailers.other_trailers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030aAdditional trailers; on the app page, these are shown after screenshots (highlights shown before)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STOREITEM_TRAILERS_VIDEOSOURCE, _STOREITEM_TRAILERS_TRAILER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9937,
  serialized_end=10917,
)

_STOREITEM_SUPPORTEDLANGUAGE = _descriptor.Descriptor(
  name='SupportedLanguage',
  full_name='StoreItem.SupportedLanguage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elanguage', full_name='StoreItem.SupportedLanguage.elanguage', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\tELanguage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported', full_name='StoreItem.SupportedLanguage.supported', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='full_audio', full_name='StoreItem.SupportedLanguage.full_audio', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subtitles', full_name='StoreItem.SupportedLanguage.subtitles', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10919,
  serialized_end=11030,
)

_STOREITEM_FREEWEEKEND = _descriptor.Descriptor(
  name='FreeWeekend',
  full_name='StoreItem.FreeWeekend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time', full_name='StoreItem.FreeWeekend.start_time', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035When the free weekend starts.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='StoreItem.FreeWeekend.end_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\033When the free weekend ends.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='StoreItem.FreeWeekend.text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302Text to show as a description of the free weekend.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11033,
  serialized_end=11222,
)

_STOREITEM = _descriptor.Descriptor(
  name='StoreItem',
  full_name='StoreItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_type', full_name='StoreItem.item_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='StoreItem.id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='StoreItem.success', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035EResult of this lookup action', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visible', full_name='StoreItem.visible', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unvailable_for_country_restriction', full_name='StoreItem.unvailable_for_country_restriction', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030MIndicates this app is visible in other regions, but not the requested reagion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='StoreItem.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='store_url_path', full_name='StoreItem.store_url_path', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030DThe URL of this item\'s store page, to be appended to STORE_BASE_URL.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='StoreItem.appid', index=7,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030AIf this is an app, or a single-app package, the steamworks appid.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='StoreItem.type', index=8,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\224\001Type of app (Game, Software, Music).  For packages/bundles, this will be the most interesting type (eg Game + Soundtrack bundle will have type Game)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='included_types', full_name='StoreItem.included_types', index=9,
      number=11, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0301For packages/bundles, all types of included items', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='included_appids', full_name='StoreItem.included_appids', index=10,
      number=12, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)For packages/bundles, all included appids', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_free', full_name='StoreItem.is_free', index=11,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_early_access', full_name='StoreItem.is_early_access', index=12,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='related_items', full_name='StoreItem.related_items', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_descriptorids', full_name='StoreItem.content_descriptorids', index=14,
      number=20, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tagids', full_name='StoreItem.tagids', index=15,
      number=21, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='categories', full_name='StoreItem.categories', index=16,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reviews', full_name='StoreItem.reviews', index=17,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basic_info', full_name='StoreItem.basic_info', index=18,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='StoreItem.tags', index=19,
      number=25, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assets', full_name='StoreItem.assets', index=20,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='release', full_name='StoreItem.release', index=21,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platforms', full_name='StoreItem.platforms', index=22,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_rating', full_name='StoreItem.game_rating', index=23,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0303Local ratings agency information, like ESRB or PEGI', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='best_purchase_option', full_name='StoreItem.best_purchase_option', index=24,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030OThe cheapest way for the user to acquire this app or package (may be a bundle).', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purchase_options', full_name='StoreItem.purchase_options', index=25,
      number=41, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030uDifferent ways to buy this app or packages (packages can be purchased directly, but may also be included in bundles).', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accessories', full_name='StoreItem.accessories', index=26,
      number=42, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030WAdditional packages or bundles associated with an app, but that do not contain the app.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='screenshots', full_name='StoreItem.screenshots', index=27,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trailers', full_name='StoreItem.trailers', index=28,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_languages', full_name='StoreItem.supported_languages', index=29,
      number=52, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='store_url_path_override', full_name='StoreItem.store_url_path_override', index=30,
      number=53, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\267\001Navigate to this URL (relative to store home) when the store capsule for this item is clicked, instead of the default /app/... URL. Used by advertising apps that point to a sale page.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='free_weekend', full_name='StoreItem.free_weekend', index=31,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'Information about a free weekend offer.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STOREITEM_RELATEDITEMS, _STOREITEM_CATEGORIES, _STOREITEM_REVIEWS, _STOREITEM_BASICINFO, _STOREITEM_TAG, _STOREITEM_ASSETS, _STOREITEM_RELEASEINFO, _STOREITEM_PLATFORMS, _STOREITEM_PURCHASEOPTION, _STOREITEM_SCREENSHOTS, _STOREITEM_TRAILERS, _STOREITEM_SUPPORTEDLANGUAGE, _STOREITEM_FREEWEEKEND, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1563,
  serialized_end=11222,
)


_CSTOREBROWSE_GETITEMS_RESPONSE = _descriptor.Descriptor(
  name='CStoreBrowse_GetItems_Response',
  full_name='CStoreBrowse_GetItems_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='store_items', full_name='CStoreBrowse_GetItems_Response.store_items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11224,
  serialized_end=11289,
)


_CSTOREBROWSE_GETSTORECATEGORIES_REQUEST = _descriptor.Descriptor(
  name='CStoreBrowse_GetStoreCategories_Request',
  full_name='CStoreBrowse_GetStoreCategories_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='CStoreBrowse_GetStoreCategories_Request.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elanguage', full_name='CStoreBrowse_GetStoreCategories_Request.elanguage', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\tELanguage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11291,
  serialized_end=11388,
)


_CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE_CATEGORY = _descriptor.Descriptor(
  name='Category',
  full_name='CStoreBrowse_GetStoreCategories_Response.Category',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='categoryid', full_name='CStoreBrowse_GetStoreCategories_Response.Category.categoryid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='CStoreBrowse_GetStoreCategories_Response.Category.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_name', full_name='CStoreBrowse_GetStoreCategories_Response.Category.internal_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='CStoreBrowse_GetStoreCategories_Response.Category.display_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_url', full_name='CStoreBrowse_GetStoreCategories_Response.Category.image_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\027Append to STORE_CDN_URL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='show_in_search', full_name='CStoreBrowse_GetStoreCategories_Response.Category.show_in_search', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030QIndicates this category can link to search results showing all items in category.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11508,
  serialized_end=11808,
)

_CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE = _descriptor.Descriptor(
  name='CStoreBrowse_GetStoreCategories_Response',
  full_name='CStoreBrowse_GetStoreCategories_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='categories', full_name='CStoreBrowse_GetStoreCategories_Response.categories', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE_CATEGORY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11391,
  serialized_end=11808,
)

_CSTOREBROWSE_GETITEMS_REQUEST.fields_by_name['ids'].message_type = _STOREITEMID
_CSTOREBROWSE_GETITEMS_REQUEST.fields_by_name['context'].message_type = _STOREBROWSECONTEXT
_CSTOREBROWSE_GETITEMS_REQUEST.fields_by_name['data_request'].message_type = _STOREBROWSEITEMDATAREQUEST
_STOREITEM_RELATEDITEMS.containing_type = _STOREITEM
_STOREITEM_CATEGORIES.containing_type = _STOREITEM
_STOREITEM_REVIEWS_STOREREVIEWSUMMARY.fields_by_name['review_score'].enum_type = _EUSERREVIEWSCORE
_STOREITEM_REVIEWS_STOREREVIEWSUMMARY.containing_type = _STOREITEM_REVIEWS
_STOREITEM_REVIEWS.fields_by_name['summary_filtered'].message_type = _STOREITEM_REVIEWS_STOREREVIEWSUMMARY
_STOREITEM_REVIEWS.fields_by_name['summary_unfiltered'].message_type = _STOREITEM_REVIEWS_STOREREVIEWSUMMARY
_STOREITEM_REVIEWS.containing_type = _STOREITEM
_STOREITEM_BASICINFO_CREATORHOMELINK.containing_type = _STOREITEM_BASICINFO
_STOREITEM_BASICINFO.fields_by_name['publishers'].message_type = _STOREITEM_BASICINFO_CREATORHOMELINK
_STOREITEM_BASICINFO.fields_by_name['developers'].message_type = _STOREITEM_BASICINFO_CREATORHOMELINK
_STOREITEM_BASICINFO.fields_by_name['franchises'].message_type = _STOREITEM_BASICINFO_CREATORHOMELINK
_STOREITEM_BASICINFO.containing_type = _STOREITEM
_STOREITEM_TAG.containing_type = _STOREITEM
_STOREITEM_ASSETS.containing_type = _STOREITEM
_STOREITEM_RELEASEINFO.containing_type = _STOREITEM
_STOREITEM_PLATFORMS_VRSUPPORT.containing_type = _STOREITEM_PLATFORMS
_STOREITEM_PLATFORMS.fields_by_name['vr_support'].message_type = _STOREITEM_PLATFORMS_VRSUPPORT
_STOREITEM_PLATFORMS.fields_by_name['steam_deck_compat_category'].enum_type = enums__pb2._ESTEAMDECKCOMPATIBILITYCATEGORY
_STOREITEM_PLATFORMS.containing_type = _STOREITEM
_STOREITEM_PURCHASEOPTION_DISCOUNT.containing_type = _STOREITEM_PURCHASEOPTION
_STOREITEM_PURCHASEOPTION.fields_by_name['active_discounts'].message_type = _STOREITEM_PURCHASEOPTION_DISCOUNT
_STOREITEM_PURCHASEOPTION.fields_by_name['user_active_discounts'].message_type = _STOREITEM_PURCHASEOPTION_DISCOUNT
_STOREITEM_PURCHASEOPTION.fields_by_name['inactive_discounts'].message_type = _STOREITEM_PURCHASEOPTION_DISCOUNT
_STOREITEM_PURCHASEOPTION.containing_type = _STOREITEM
_STOREITEM_SCREENSHOTS_SCREENSHOT.containing_type = _STOREITEM_SCREENSHOTS
_STOREITEM_SCREENSHOTS.fields_by_name['all_ages_screenshots'].message_type = _STOREITEM_SCREENSHOTS_SCREENSHOT
_STOREITEM_SCREENSHOTS.fields_by_name['mature_content_screenshots'].message_type = _STOREITEM_SCREENSHOTS_SCREENSHOT
_STOREITEM_SCREENSHOTS.containing_type = _STOREITEM
_STOREITEM_TRAILERS_VIDEOSOURCE.containing_type = _STOREITEM_TRAILERS
_STOREITEM_TRAILERS_TRAILER.fields_by_name['trailer_480p'].message_type = _STOREITEM_TRAILERS_VIDEOSOURCE
_STOREITEM_TRAILERS_TRAILER.fields_by_name['trailer_max'].message_type = _STOREITEM_TRAILERS_VIDEOSOURCE
_STOREITEM_TRAILERS_TRAILER.fields_by_name['microtrailer'].message_type = _STOREITEM_TRAILERS_VIDEOSOURCE
_STOREITEM_TRAILERS_TRAILER.containing_type = _STOREITEM_TRAILERS
_STOREITEM_TRAILERS.fields_by_name['highlights'].message_type = _STOREITEM_TRAILERS_TRAILER
_STOREITEM_TRAILERS.fields_by_name['other_trailers'].message_type = _STOREITEM_TRAILERS_TRAILER
_STOREITEM_TRAILERS.containing_type = _STOREITEM
_STOREITEM_SUPPORTEDLANGUAGE.containing_type = _STOREITEM
_STOREITEM_FREEWEEKEND.containing_type = _STOREITEM
_STOREITEM.fields_by_name['item_type'].enum_type = _ESTOREITEMTYPE
_STOREITEM.fields_by_name['type'].enum_type = _ESTOREAPPTYPE
_STOREITEM.fields_by_name['included_types'].enum_type = _ESTOREAPPTYPE
_STOREITEM.fields_by_name['related_items'].message_type = _STOREITEM_RELATEDITEMS
_STOREITEM.fields_by_name['content_descriptorids'].enum_type = enums__productinfo__pb2._ECONTENTDESCRIPTORID
_STOREITEM.fields_by_name['categories'].message_type = _STOREITEM_CATEGORIES
_STOREITEM.fields_by_name['reviews'].message_type = _STOREITEM_REVIEWS
_STOREITEM.fields_by_name['basic_info'].message_type = _STOREITEM_BASICINFO
_STOREITEM.fields_by_name['tags'].message_type = _STOREITEM_TAG
_STOREITEM.fields_by_name['assets'].message_type = _STOREITEM_ASSETS
_STOREITEM.fields_by_name['release'].message_type = _STOREITEM_RELEASEINFO
_STOREITEM.fields_by_name['platforms'].message_type = _STOREITEM_PLATFORMS
_STOREITEM.fields_by_name['game_rating'].message_type = _STOREGAMERATING
_STOREITEM.fields_by_name['best_purchase_option'].message_type = _STOREITEM_PURCHASEOPTION
_STOREITEM.fields_by_name['purchase_options'].message_type = _STOREITEM_PURCHASEOPTION
_STOREITEM.fields_by_name['accessories'].message_type = _STOREITEM_PURCHASEOPTION
_STOREITEM.fields_by_name['screenshots'].message_type = _STOREITEM_SCREENSHOTS
_STOREITEM.fields_by_name['trailers'].message_type = _STOREITEM_TRAILERS
_STOREITEM.fields_by_name['supported_languages'].message_type = _STOREITEM_SUPPORTEDLANGUAGE
_STOREITEM.fields_by_name['free_weekend'].message_type = _STOREITEM_FREEWEEKEND
_CSTOREBROWSE_GETITEMS_RESPONSE.fields_by_name['store_items'].message_type = _STOREITEM
_CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE_CATEGORY.fields_by_name['type'].enum_type = _ESTORECATEGORYTYPE
_CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE_CATEGORY.containing_type = _CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE
_CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE.fields_by_name['categories'].message_type = _CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE_CATEGORY
DESCRIPTOR.message_types_by_name['StoreItemID'] = _STOREITEMID
DESCRIPTOR.message_types_by_name['StoreBrowseContext'] = _STOREBROWSECONTEXT
DESCRIPTOR.message_types_by_name['StoreBrowseItemDataRequest'] = _STOREBROWSEITEMDATAREQUEST
DESCRIPTOR.message_types_by_name['CStoreBrowse_GetItems_Request'] = _CSTOREBROWSE_GETITEMS_REQUEST
DESCRIPTOR.message_types_by_name['StoreGameRating'] = _STOREGAMERATING
DESCRIPTOR.message_types_by_name['StoreItem'] = _STOREITEM
DESCRIPTOR.message_types_by_name['CStoreBrowse_GetItems_Response'] = _CSTOREBROWSE_GETITEMS_RESPONSE
DESCRIPTOR.message_types_by_name['CStoreBrowse_GetStoreCategories_Request'] = _CSTOREBROWSE_GETSTORECATEGORIES_REQUEST
DESCRIPTOR.message_types_by_name['CStoreBrowse_GetStoreCategories_Response'] = _CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE
DESCRIPTOR.enum_types_by_name['EStoreItemType'] = _ESTOREITEMTYPE
DESCRIPTOR.enum_types_by_name['EStoreAppType'] = _ESTOREAPPTYPE
DESCRIPTOR.enum_types_by_name['EUserReviewScore'] = _EUSERREVIEWSCORE
DESCRIPTOR.enum_types_by_name['EStoreCategoryType'] = _ESTORECATEGORYTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StoreItemID = _reflection.GeneratedProtocolMessageType('StoreItemID', (_message.Message,), {
  'DESCRIPTOR' : _STOREITEMID,
  '__module__' : 'steammessages_storebrowse_pb2'
  # @@protoc_insertion_point(class_scope:StoreItemID)
  })
_sym_db.RegisterMessage(StoreItemID)

StoreBrowseContext = _reflection.GeneratedProtocolMessageType('StoreBrowseContext', (_message.Message,), {
  'DESCRIPTOR' : _STOREBROWSECONTEXT,
  '__module__' : 'steammessages_storebrowse_pb2'
  # @@protoc_insertion_point(class_scope:StoreBrowseContext)
  })
_sym_db.RegisterMessage(StoreBrowseContext)

StoreBrowseItemDataRequest = _reflection.GeneratedProtocolMessageType('StoreBrowseItemDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOREBROWSEITEMDATAREQUEST,
  '__module__' : 'steammessages_storebrowse_pb2'
  # @@protoc_insertion_point(class_scope:StoreBrowseItemDataRequest)
  })
_sym_db.RegisterMessage(StoreBrowseItemDataRequest)

CStoreBrowse_GetItems_Request = _reflection.GeneratedProtocolMessageType('CStoreBrowse_GetItems_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTOREBROWSE_GETITEMS_REQUEST,
  '__module__' : 'steammessages_storebrowse_pb2'
  # @@protoc_insertion_point(class_scope:CStoreBrowse_GetItems_Request)
  })
_sym_db.RegisterMessage(CStoreBrowse_GetItems_Request)

StoreGameRating = _reflection.GeneratedProtocolMessageType('StoreGameRating', (_message.Message,), {
  'DESCRIPTOR' : _STOREGAMERATING,
  '__module__' : 'steammessages_storebrowse_pb2'
  # @@protoc_insertion_point(class_scope:StoreGameRating)
  })
_sym_db.RegisterMessage(StoreGameRating)

StoreItem = _reflection.GeneratedProtocolMessageType('StoreItem', (_message.Message,), {

  'RelatedItems' : _reflection.GeneratedProtocolMessageType('RelatedItems', (_message.Message,), {
    'DESCRIPTOR' : _STOREITEM_RELATEDITEMS,
    '__module__' : 'steammessages_storebrowse_pb2'
    # @@protoc_insertion_point(class_scope:StoreItem.RelatedItems)
    })
  ,

  'Categories' : _reflection.GeneratedProtocolMessageType('Categories', (_message.Message,), {
    'DESCRIPTOR' : _STOREITEM_CATEGORIES,
    '__module__' : 'steammessages_storebrowse_pb2'
    # @@protoc_insertion_point(class_scope:StoreItem.Categories)
    })
  ,

  'Reviews' : _reflection.GeneratedProtocolMessageType('Reviews', (_message.Message,), {

    'StoreReviewSummary' : _reflection.GeneratedProtocolMessageType('StoreReviewSummary', (_message.Message,), {
      'DESCRIPTOR' : _STOREITEM_REVIEWS_STOREREVIEWSUMMARY,
      '__module__' : 'steammessages_storebrowse_pb2'
      # @@protoc_insertion_point(class_scope:StoreItem.Reviews.StoreReviewSummary)
      })
    ,
    'DESCRIPTOR' : _STOREITEM_REVIEWS,
    '__module__' : 'steammessages_storebrowse_pb2'
    # @@protoc_insertion_point(class_scope:StoreItem.Reviews)
    })
  ,

  'BasicInfo' : _reflection.GeneratedProtocolMessageType('BasicInfo', (_message.Message,), {

    'CreatorHomeLink' : _reflection.GeneratedProtocolMessageType('CreatorHomeLink', (_message.Message,), {
      'DESCRIPTOR' : _STOREITEM_BASICINFO_CREATORHOMELINK,
      '__module__' : 'steammessages_storebrowse_pb2'
      # @@protoc_insertion_point(class_scope:StoreItem.BasicInfo.CreatorHomeLink)
      })
    ,
    'DESCRIPTOR' : _STOREITEM_BASICINFO,
    '__module__' : 'steammessages_storebrowse_pb2'
    # @@protoc_insertion_point(class_scope:StoreItem.BasicInfo)
    })
  ,

  'Tag' : _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
    'DESCRIPTOR' : _STOREITEM_TAG,
    '__module__' : 'steammessages_storebrowse_pb2'
    # @@protoc_insertion_point(class_scope:StoreItem.Tag)
    })
  ,

  'Assets' : _reflection.GeneratedProtocolMessageType('Assets', (_message.Message,), {
    'DESCRIPTOR' : _STOREITEM_ASSETS,
    '__module__' : 'steammessages_storebrowse_pb2'
    # @@protoc_insertion_point(class_scope:StoreItem.Assets)
    })
  ,

  'ReleaseInfo' : _reflection.GeneratedProtocolMessageType('ReleaseInfo', (_message.Message,), {
    'DESCRIPTOR' : _STOREITEM_RELEASEINFO,
    '__module__' : 'steammessages_storebrowse_pb2'
    # @@protoc_insertion_point(class_scope:StoreItem.ReleaseInfo)
    })
  ,

  'Platforms' : _reflection.GeneratedProtocolMessageType('Platforms', (_message.Message,), {

    'VRSupport' : _reflection.GeneratedProtocolMessageType('VRSupport', (_message.Message,), {
      'DESCRIPTOR' : _STOREITEM_PLATFORMS_VRSUPPORT,
      '__module__' : 'steammessages_storebrowse_pb2'
      # @@protoc_insertion_point(class_scope:StoreItem.Platforms.VRSupport)
      })
    ,
    'DESCRIPTOR' : _STOREITEM_PLATFORMS,
    '__module__' : 'steammessages_storebrowse_pb2'
    # @@protoc_insertion_point(class_scope:StoreItem.Platforms)
    })
  ,

  'PurchaseOption' : _reflection.GeneratedProtocolMessageType('PurchaseOption', (_message.Message,), {

    'Discount' : _reflection.GeneratedProtocolMessageType('Discount', (_message.Message,), {
      'DESCRIPTOR' : _STOREITEM_PURCHASEOPTION_DISCOUNT,
      '__module__' : 'steammessages_storebrowse_pb2'
      # @@protoc_insertion_point(class_scope:StoreItem.PurchaseOption.Discount)
      })
    ,
    'DESCRIPTOR' : _STOREITEM_PURCHASEOPTION,
    '__module__' : 'steammessages_storebrowse_pb2'
    # @@protoc_insertion_point(class_scope:StoreItem.PurchaseOption)
    })
  ,

  'Screenshots' : _reflection.GeneratedProtocolMessageType('Screenshots', (_message.Message,), {

    'Screenshot' : _reflection.GeneratedProtocolMessageType('Screenshot', (_message.Message,), {
      'DESCRIPTOR' : _STOREITEM_SCREENSHOTS_SCREENSHOT,
      '__module__' : 'steammessages_storebrowse_pb2'
      # @@protoc_insertion_point(class_scope:StoreItem.Screenshots.Screenshot)
      })
    ,
    'DESCRIPTOR' : _STOREITEM_SCREENSHOTS,
    '__module__' : 'steammessages_storebrowse_pb2'
    # @@protoc_insertion_point(class_scope:StoreItem.Screenshots)
    })
  ,

  'Trailers' : _reflection.GeneratedProtocolMessageType('Trailers', (_message.Message,), {

    'VideoSource' : _reflection.GeneratedProtocolMessageType('VideoSource', (_message.Message,), {
      'DESCRIPTOR' : _STOREITEM_TRAILERS_VIDEOSOURCE,
      '__module__' : 'steammessages_storebrowse_pb2'
      # @@protoc_insertion_point(class_scope:StoreItem.Trailers.VideoSource)
      })
    ,

    'Trailer' : _reflection.GeneratedProtocolMessageType('Trailer', (_message.Message,), {
      'DESCRIPTOR' : _STOREITEM_TRAILERS_TRAILER,
      '__module__' : 'steammessages_storebrowse_pb2'
      # @@protoc_insertion_point(class_scope:StoreItem.Trailers.Trailer)
      })
    ,
    'DESCRIPTOR' : _STOREITEM_TRAILERS,
    '__module__' : 'steammessages_storebrowse_pb2'
    # @@protoc_insertion_point(class_scope:StoreItem.Trailers)
    })
  ,

  'SupportedLanguage' : _reflection.GeneratedProtocolMessageType('SupportedLanguage', (_message.Message,), {
    'DESCRIPTOR' : _STOREITEM_SUPPORTEDLANGUAGE,
    '__module__' : 'steammessages_storebrowse_pb2'
    # @@protoc_insertion_point(class_scope:StoreItem.SupportedLanguage)
    })
  ,

  'FreeWeekend' : _reflection.GeneratedProtocolMessageType('FreeWeekend', (_message.Message,), {
    'DESCRIPTOR' : _STOREITEM_FREEWEEKEND,
    '__module__' : 'steammessages_storebrowse_pb2'
    # @@protoc_insertion_point(class_scope:StoreItem.FreeWeekend)
    })
  ,
  'DESCRIPTOR' : _STOREITEM,
  '__module__' : 'steammessages_storebrowse_pb2'
  # @@protoc_insertion_point(class_scope:StoreItem)
  })
_sym_db.RegisterMessage(StoreItem)
_sym_db.RegisterMessage(StoreItem.RelatedItems)
_sym_db.RegisterMessage(StoreItem.Categories)
_sym_db.RegisterMessage(StoreItem.Reviews)
_sym_db.RegisterMessage(StoreItem.Reviews.StoreReviewSummary)
_sym_db.RegisterMessage(StoreItem.BasicInfo)
_sym_db.RegisterMessage(StoreItem.BasicInfo.CreatorHomeLink)
_sym_db.RegisterMessage(StoreItem.Tag)
_sym_db.RegisterMessage(StoreItem.Assets)
_sym_db.RegisterMessage(StoreItem.ReleaseInfo)
_sym_db.RegisterMessage(StoreItem.Platforms)
_sym_db.RegisterMessage(StoreItem.Platforms.VRSupport)
_sym_db.RegisterMessage(StoreItem.PurchaseOption)
_sym_db.RegisterMessage(StoreItem.PurchaseOption.Discount)
_sym_db.RegisterMessage(StoreItem.Screenshots)
_sym_db.RegisterMessage(StoreItem.Screenshots.Screenshot)
_sym_db.RegisterMessage(StoreItem.Trailers)
_sym_db.RegisterMessage(StoreItem.Trailers.VideoSource)
_sym_db.RegisterMessage(StoreItem.Trailers.Trailer)
_sym_db.RegisterMessage(StoreItem.SupportedLanguage)
_sym_db.RegisterMessage(StoreItem.FreeWeekend)

CStoreBrowse_GetItems_Response = _reflection.GeneratedProtocolMessageType('CStoreBrowse_GetItems_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTOREBROWSE_GETITEMS_RESPONSE,
  '__module__' : 'steammessages_storebrowse_pb2'
  # @@protoc_insertion_point(class_scope:CStoreBrowse_GetItems_Response)
  })
_sym_db.RegisterMessage(CStoreBrowse_GetItems_Response)

CStoreBrowse_GetStoreCategories_Request = _reflection.GeneratedProtocolMessageType('CStoreBrowse_GetStoreCategories_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTOREBROWSE_GETSTORECATEGORIES_REQUEST,
  '__module__' : 'steammessages_storebrowse_pb2'
  # @@protoc_insertion_point(class_scope:CStoreBrowse_GetStoreCategories_Request)
  })
_sym_db.RegisterMessage(CStoreBrowse_GetStoreCategories_Request)

CStoreBrowse_GetStoreCategories_Response = _reflection.GeneratedProtocolMessageType('CStoreBrowse_GetStoreCategories_Response', (_message.Message,), {

  'Category' : _reflection.GeneratedProtocolMessageType('Category', (_message.Message,), {
    'DESCRIPTOR' : _CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE_CATEGORY,
    '__module__' : 'steammessages_storebrowse_pb2'
    # @@protoc_insertion_point(class_scope:CStoreBrowse_GetStoreCategories_Response.Category)
    })
  ,
  'DESCRIPTOR' : _CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE,
  '__module__' : 'steammessages_storebrowse_pb2'
  # @@protoc_insertion_point(class_scope:CStoreBrowse_GetStoreCategories_Response)
  })
_sym_db.RegisterMessage(CStoreBrowse_GetStoreCategories_Response)
_sym_db.RegisterMessage(CStoreBrowse_GetStoreCategories_Response.Category)


DESCRIPTOR._options = None
_STOREBROWSECONTEXT.fields_by_name['elanguage']._options = None
_STOREBROWSECONTEXT.fields_by_name['country_code']._options = None
_STOREBROWSECONTEXT.fields_by_name['steam_realm']._options = None
_STOREBROWSEITEMDATAREQUEST.fields_by_name['include_tag_count']._options = None
_STOREBROWSEITEMDATAREQUEST.fields_by_name['include_basic_info']._options = None
_STOREBROWSEITEMDATAREQUEST.fields_by_name['include_supported_languages']._options = None
_STOREGAMERATING.fields_by_name['type']._options = None
_STOREGAMERATING.fields_by_name['rating']._options = None
_STOREGAMERATING.fields_by_name['descriptors']._options = None
_STOREGAMERATING.fields_by_name['interactive_elements']._options = None
_STOREGAMERATING.fields_by_name['required_age']._options = None
_STOREGAMERATING.fields_by_name['image_url']._options = None
_STOREGAMERATING.fields_by_name['image_target']._options = None
_STOREITEM_RELATEDITEMS.fields_by_name['parent_appid']._options = None
_STOREITEM_CATEGORIES.fields_by_name['supported_player_categoryids']._options = None
_STOREITEM_CATEGORIES.fields_by_name['feature_categoryids']._options = None
_STOREITEM_CATEGORIES.fields_by_name['controller_categoryids']._options = None
_STOREITEM_REVIEWS_STOREREVIEWSUMMARY.fields_by_name['percent_positive']._options = None
_STOREITEM_REVIEWS_STOREREVIEWSUMMARY.fields_by_name['review_score_label']._options = None
_STOREITEM_REVIEWS.fields_by_name['summary_filtered']._options = None
_STOREITEM_REVIEWS.fields_by_name['summary_unfiltered']._options = None
_STOREITEM_BASICINFO_CREATORHOMELINK.fields_by_name['creator_clan_account_id']._options = None
_STOREITEM_BASICINFO.fields_by_name['capsule_headline']._options = None
_STOREITEM_ASSETS.fields_by_name['asset_url_format']._options = None
_STOREITEM_ASSETS.fields_by_name['header']._options = None
_STOREITEM_ASSETS.fields_by_name['package_header']._options = None
_STOREITEM_ASSETS.fields_by_name['hero_capsule']._options = None
_STOREITEM_ASSETS.fields_by_name['hero_capsule_2x']._options = None
_STOREITEM_ASSETS.fields_by_name['library_capsule']._options = None
_STOREITEM_ASSETS.fields_by_name['library_capsule_2x']._options = None
_STOREITEM_ASSETS.fields_by_name['library_hero']._options = None
_STOREITEM_ASSETS.fields_by_name['library_hero_2x']._options = None
_STOREITEM_ASSETS.fields_by_name['community_icon']._options = None
_STOREITEM_RELEASEINFO.fields_by_name['steam_release_date']._options = None
_STOREITEM_RELEASEINFO.fields_by_name['original_release_date']._options = None
_STOREITEM_RELEASEINFO.fields_by_name['original_steam_release_date']._options = None
_STOREITEM_RELEASEINFO.fields_by_name['is_coming_soon']._options = None
_STOREITEM_RELEASEINFO.fields_by_name['is_preload']._options = None
_STOREITEM_RELEASEINFO.fields_by_name['custom_release_date_message']._options = None
_STOREITEM_RELEASEINFO.fields_by_name['is_abridged_release_date']._options = None
_STOREITEM_RELEASEINFO.fields_by_name['coming_soon_display']._options = None
_STOREITEM_PURCHASEOPTION.fields_by_name['purchase_option_name']._options = None
_STOREITEM_PURCHASEOPTION.fields_by_name['final_price_in_cents']._options = None
_STOREITEM_PURCHASEOPTION.fields_by_name['original_price_in_cents']._options = None
_STOREITEM_PURCHASEOPTION.fields_by_name['formatted_final_price']._options = None
_STOREITEM_PURCHASEOPTION.fields_by_name['discount_pct']._options = None
_STOREITEM_PURCHASEOPTION.fields_by_name['bundle_discount_pct']._options = None
_STOREITEM_PURCHASEOPTION.fields_by_name['active_discounts']._options = None
_STOREITEM_PURCHASEOPTION.fields_by_name['user_active_discounts']._options = None
_STOREITEM_PURCHASEOPTION.fields_by_name['inactive_discounts']._options = None
_STOREITEM_PURCHASEOPTION.fields_by_name['is_commercial_license']._options = None
_STOREITEM_PURCHASEOPTION.fields_by_name['should_suppress_discount_pct']._options = None
_STOREITEM_SCREENSHOTS_SCREENSHOT.fields_by_name['filename']._options = None
_STOREITEM_SCREENSHOTS_SCREENSHOT.fields_by_name['ordinal']._options = None
_STOREITEM_SCREENSHOTS.fields_by_name['all_ages_screenshots']._options = None
_STOREITEM_SCREENSHOTS.fields_by_name['mature_content_screenshots']._options = None
_STOREITEM_TRAILERS_VIDEOSOURCE.fields_by_name['filename']._options = None
_STOREITEM_TRAILERS_VIDEOSOURCE.fields_by_name['type']._options = None
_STOREITEM_TRAILERS_TRAILER.fields_by_name['trailer_url_format']._options = None
_STOREITEM_TRAILERS_TRAILER.fields_by_name['screenshot_medium']._options = None
_STOREITEM_TRAILERS_TRAILER.fields_by_name['screenshot_full']._options = None
_STOREITEM_TRAILERS_TRAILER.fields_by_name['trailer_base_id']._options = None
_STOREITEM_TRAILERS.fields_by_name['highlights']._options = None
_STOREITEM_TRAILERS.fields_by_name['other_trailers']._options = None
_STOREITEM_SUPPORTEDLANGUAGE.fields_by_name['elanguage']._options = None
_STOREITEM_FREEWEEKEND.fields_by_name['start_time']._options = None
_STOREITEM_FREEWEEKEND.fields_by_name['end_time']._options = None
_STOREITEM_FREEWEEKEND.fields_by_name['text']._options = None
_STOREITEM.fields_by_name['success']._options = None
_STOREITEM.fields_by_name['unvailable_for_country_restriction']._options = None
_STOREITEM.fields_by_name['store_url_path']._options = None
_STOREITEM.fields_by_name['appid']._options = None
_STOREITEM.fields_by_name['type']._options = None
_STOREITEM.fields_by_name['included_types']._options = None
_STOREITEM.fields_by_name['included_appids']._options = None
_STOREITEM.fields_by_name['game_rating']._options = None
_STOREITEM.fields_by_name['best_purchase_option']._options = None
_STOREITEM.fields_by_name['purchase_options']._options = None
_STOREITEM.fields_by_name['accessories']._options = None
_STOREITEM.fields_by_name['store_url_path_override']._options = None
_STOREITEM.fields_by_name['free_weekend']._options = None
_CSTOREBROWSE_GETSTORECATEGORIES_REQUEST.fields_by_name['elanguage']._options = None
_CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE_CATEGORY.fields_by_name['image_url']._options = None
_CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE_CATEGORY.fields_by_name['show_in_search']._options = None

_STOREBROWSE = _descriptor.ServiceDescriptor(
  name='StoreBrowse',
  full_name='StoreBrowse',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\"APIs for accessing store item data',
  create_key=_descriptor._internal_create_key,
  serialized_start=13049,
  serialized_end=13476,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetItems',
    full_name='StoreBrowse.GetItems',
    index=0,
    containing_service=None,
    input_type=_CSTOREBROWSE_GETITEMS_REQUEST,
    output_type=_CSTOREBROWSE_GETITEMS_RESPONSE,
    serialized_options=b'\202\265\030(Get information about items on the store',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStoreCategories',
    full_name='StoreBrowse.GetStoreCategories',
    index=1,
    containing_service=None,
    input_type=_CSTOREBROWSE_GETSTORECATEGORIES_REQUEST,
    output_type=_CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE,
    serialized_options=b'\202\265\030\207\001Get category definitions for store.  This is a public-facing API (as compared to StoreCatalog.GetCategories, which is intended for PHP)',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STOREBROWSE)

DESCRIPTOR.services_by_name['StoreBrowse'] = _STOREBROWSE

StoreBrowse = service_reflection.GeneratedServiceType('StoreBrowse', (_service.Service,), dict(
  DESCRIPTOR = _STOREBROWSE,
  __module__ = 'steammessages_storebrowse_pb2'
  ))

StoreBrowse_Stub = service_reflection.GeneratedServiceStubType('StoreBrowse_Stub', (StoreBrowse,), dict(
  DESCRIPTOR = _STOREBROWSE,
  __module__ = 'steammessages_storebrowse_pb2'
  ))


# @@protoc_insertion_point(module_scope)
